==> ejc-analyticdatas-impl-3.0.0-20230621.014837-31-sources.jar: com/ejianc/foundation/analyticdatas/bean/BehaviorDataAnalyticEntity.java <==
package com.ejianc.foundation.analyticdatas.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

@TableName("ejc_analyticdatas_behaviordata")
public class BehaviorDataAnalyticEntity extends BaseEntity {

	private static final long serialVersionUID = 1L;

	@TableField(value = "device_id")
	private String deviceId; // 访问设备

	@TableField(value = "province")
	private String province; // 省

	@TableField(value = "city")
	private String city; // 市

	@TableField(value = "ipaddr")
	private String ipAddr; // ip地址

	@TableField(value = "operators")
	private String operators; // 运营商

	@TableField(value = "user_id")
	private String userId; // 用户ID

	@TableField(value = "company_name")
	private String companyName; // 用户公司

	@TableField(value = "company_type")
	private String companyType; // 用户公司类型 对应企业类型

	@TableField(value = "user_name")
	private String userName; // 用户姓名

	@TableField(value = "user_mobile")
	private String userMobile; // 用户手机号

	@TableField(value = "app_id")
	private String appId; // 应用ID

	@TableField(value = "app_name")
	private String appName; // 应用名称

	@TableField(value = "event_code")
	private String eventCode; // 事件编码

	@TableField(value = "operate_time")
	private Date operateTime; // 操作时间

	@TableField(value = "req_from")
	private String reqFrom; // 请求来源 pc 或者 mobile

	public String getDeviceId() {
		return deviceId;
	}

	public void setDeviceId(String deviceId) {
		this.deviceId = deviceId;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getIpAddr() {
		return ipAddr;
	}

	public void setIpAddr(String ipAddr) {
		this.ipAddr = ipAddr;
	}

	public String getOperators() {
		return operators;
	}

	public void setOperators(String operators) {
		this.operators = operators;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserMobile() {
		return userMobile;
	}

	public void setUserMobile(String userMobile) {
		this.userMobile = userMobile;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getEventCode() {
		return eventCode;
	}

	public void setEventCode(String eventCode) {
		this.eventCode = eventCode;
	}

	public Date getOperateTime() {
		return operateTime;
	}

	public void setOperateTime(Date operateTime) {
		this.operateTime = operateTime;
	}

	public String getReqFrom() {
		return reqFrom;
	}

	public void setReqFrom(String reqFrom) {
		this.reqFrom = reqFrom;
	}

	public String getCompanyType() {
		return companyType;
	}

	public void setCompanyType(String companyType) {
		this.companyType = companyType;
	}
}

==> ejc-analyticdatas-impl-3.0.0-20240521.051532-53-sources.jar: com/ejianc/foundation/analyticdatas/bean/BehaviorDataAnalyticEntity.java <==
package com.ejianc.foundation.analyticdatas.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

@TableName("ejc_analyticdatas_behaviordata")
public class BehaviorDataAnalyticEntity extends BaseEntity {

	private static final long serialVersionUID = 1L;

	@TableField(value = "device_id")
	private String deviceId; // 访问设备

	@TableField(value = "province")
	private String province; // 省

	@TableField(value = "city")
	private String city; // 市

	@TableField(value = "ipaddr")
	private String ipAddr; // ip地址

	@TableField(value = "operators")
	private String operators; // 运营商

	@TableField(value = "user_id")
	private String userId; // 用户ID

	@TableField(value = "company_name")
	private String companyName; // 用户公司

	@TableField(value = "company_type")
	private String companyType; // 用户公司类型 对应企业类型

	@TableField(value = "user_name")
	private String userName; // 用户姓名

	@TableField(value = "user_mobile")
	private String userMobile; // 用户手机号

	@TableField(value = "app_id")
	private String appId; // 应用ID

	@TableField(value = "app_name")
	private String appName; // 应用名称

	@TableField(value = "event_code")
	private String eventCode; // 事件编码

	@TableField(value = "operate_time")
	private Date operateTime; // 操作时间

	@TableField(value = "req_from")
	private String reqFrom; // 请求来源 pc 或者 mobile

	@TableField(value = "operate_org_id")
	private Long operateOrgId; // 操作组织

	@TableField(value = "operate_org_name")
	private String operateOrgName; // 操作组织名称

	@TableField(value = "operate_org_code")
	private String operateOrgCode;

	@TableField(value = "department_id")
	private Long departmentId;

	@TableField(value = "department_name")
	private String departmentName;

	@TableField(value = "operate_org_type")
	private Integer operateOrgType;

	/**
	 * 员工ID
	 */
	@TableField(value = "employee_id")
	private Long employeeId;

	/**
	 * 员工姓名
	 */
	@TableField(value = "employee_name")
	private String employeeName;

	public String getDeviceId() {
		return deviceId;
	}

	public void setDeviceId(String deviceId) {
		this.deviceId = deviceId;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getIpAddr() {
		return ipAddr;
	}

	public void setIpAddr(String ipAddr) {
		this.ipAddr = ipAddr;
	}

	public String getOperators() {
		return operators;
	}

	public void setOperators(String operators) {
		this.operators = operators;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	public String getUserMobile() {
		return userMobile;
	}

	public void setUserMobile(String userMobile) {
		this.userMobile = userMobile;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}

	public String getEventCode() {
		return eventCode;
	}

	public void setEventCode(String eventCode) {
		this.eventCode = eventCode;
	}

	public Date getOperateTime() {
		return operateTime;
	}

	public void setOperateTime(Date operateTime) {
		this.operateTime = operateTime;
	}

	public String getReqFrom() {
		return reqFrom;
	}

	public void setReqFrom(String reqFrom) {
		this.reqFrom = reqFrom;
	}

	public String getCompanyType() {
		return companyType;
	}

	public void setCompanyType(String companyType) {
		this.companyType = companyType;
	}

	public Long getOperateOrgId() {
		return operateOrgId;
	}

	public void setOperateOrgId(Long operateOrgId) {
		this.operateOrgId = operateOrgId;
	}

	public String getOperateOrgName() {
		return operateOrgName;
	}

	public void setOperateOrgName(String operateOrgName) {
		this.operateOrgName = operateOrgName;
	}

	public String getOperateOrgCode() {
		return operateOrgCode;
	}

	public void setOperateOrgCode(String operateOrgCode) {
		this.operateOrgCode = operateOrgCode;
	}

	public Long getDepartmentId() {
		return departmentId;
	}

	public void setDepartmentId(Long departmentId) {
		this.departmentId = departmentId;
	}

	public String getDepartmentName() {
		return departmentName;
	}

	public void setDepartmentName(String departmentName) {
		this.departmentName = departmentName;
	}

	public Integer getOperateOrgType() {
		return operateOrgType;
	}

	public void setOperateOrgType(Integer operateOrgType) {
		this.operateOrgType = operateOrgType;
	}

	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}
}
